#
# spec file for package python-treq
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-treq
Version:        24.9.1
Release:        1.3
Summary:        HTTP library inspired by python-requests
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/twisted/treq
Source:         https://files.pythonhosted.org/packages/source/t/treq/treq-%{version}.tar.gz
BuildRequires:  %{python_module Twisted-tls >= 22.10.0}
BuildRequires:  %{python_module attrs}
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module httpbin}
BuildRequires:  %{python_module hyperlink >= 21.0.0}
BuildRequires:  %{python_module incremental}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module requests >= 2.1.0}
BuildRequires:  %{python_module service_identity}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing-extensions >= 3.10.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Twisted-tls >= 22.10.0
Requires:       python-attrs
Requires:       python-hyperlink >= 21.0.0
Requires:       python-incremental
Requires:       python-requests >= 2.1.0
Requires:       python-typing-extensions >= 3.10.0
BuildArch:      noarch
%python_subpackages

%description
treq is an HTTP library inspired by requests but written on top of Twisted’s Agents.
It provides a simple, higher level API for making HTTP requests when using Twisted.

%prep
%setup -q -n treq-%{version}
%autopatch -p1

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/treq

%check
export PYTHONDONTWRITEBYTECODE=1
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} %{_bindir}/trial-%{$python_bin_suffix} treq

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/treq
%{python_sitelib}/treq-%{version}*-info/

%changelog
* Tue Oct 29 2024 Dirk Müller <dmueller@suse.com>
- update to 24.9.1:
  * treq has vendored its dependency on the multipart library to
    avoid import conflicts with python-multipart; it should now
    be installable alongside that library.
  * treq now ships type annotations.
  * The new :mod:`treq.cookies` module provides helper functions
    for working with http.cookiejar.Cookie and CookieJar objects.
  * Python 3.13 is now supported.
  * :mod:`treq.content.text_content()` no longer generates
    deprecation warnings due to use of the cgi module.
  * Mixing the json argument with files or data now raises
    TypeError.
  * Passing non-string (str or bytes) values as part of a dict to
    the headers argument now results in a TypeError, as does
    passing any collection other than a dict or Headers instance.
  * Support for Python 3.7 and PyPy 3.8, which have reached end
    of support, has been dropped.
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 23.11.0:
  * When the collector passed to ``treq.collect(response,
    collector)`` throws an exception, that error will now be
    returned to the caller of ``collect()`` via the result
    ``Deferred``, and the underlying HTTP transport will be
    closed.
  * Python 3.11 is now supported.
  * Python 3.12 is now supported.
  * PyPy 3.9 is now supported.
  * PyPy 3.10 is now supported.
  * Deprecations and Removals
  * The minimum supported Twisted version has increased to
    22.10.0. Older versions are no longer tested in CI.
  * Support for Python 3.6, which has reached end of support, has
    been dropped.
  * Support for PyPy 3.7, which has reached end of support, has
    been removed.
  * Support for PyPy 3.8, which has reached end of support, is
    deprecated.
* Sun Jun 11 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue Jun 21 2022 Ben Greiner <code@bnavigator.de>
- Actually requires twisted[tls]: python-Twisted-tls on Tumbleweed
* Tue Jun  7 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to 22.2.0
  - Features
  - Python 3.10 and PyPy 3.8 are now supported. (`#338
    <https://github.com/twisted/treq/issues/338>`__)
  - Bugfixes
  - Address a regression introduced in Treq 22.1.0 that prevented
    transmission of cookies with requests to ports other than 80,
    including HTTPS (443). (`#343
    <https://github.com/twisted/treq/issues/343>`__)
  - Deprecations and Removals
  - Support for Python 3.6, which has reached end of support, is
    deprecated. This is the last release with support for Python
    3.6. (`#338 <https://github.com/twisted/treq/issues/338>`__)
* Thu Feb  3 2022 Matej Cepl <mcepl@suse.com>
- Update to 22.1.0
  - Cookies specified as a dict were sent to every domain, not
    just the domain of the request, potentially exposing them on
    redirect. See GHSA-fhpf-pp6p-55qc, CVE-2022-23607, bsc#1195432
  - PEP 517/518 build-system metadata is now provided in
    pyproject.toml.
  - treq.testing.StubTreq now persists twisted.web.server.Session
    instances between requests.
  - The dependency on Sphinx required to build the documentation
    has been moved from the dev extra to the new docs
    extra.
  - Support for Python 2.7 and 3.5 has been dropped. treq no
    longer depends on six or mock.
- Switch to pyproject* tool chain.
* Thu Mar 18 2021 Aleksa Sarai <asarai@suse.com>
- Update to 21.1.0. bsc#1183679
  * Support for Python 3.9.
  * Support for Twisted >= 20.9.0.
  * Support for Python 2.7 and 3.5 (which are both EOL) is deprecated.
  * The auth parameter now accepts arbitrary text and bytes for usernames and
    passwords. Text is encoded as UTF-8, per RFC 7617. Previously only ASCII
    was allowed.
  * treq produces a more helpful exception when passed a tuple of the wrong
    size in the files parameter.
  * The url parameter of HTTPClient.request() (and shortcuts like get()) now
    accept hyperlink.DecodedURL and hyperlink.URL in addition to str and bytes.
* Thu Jul 23 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 20.4.1
  * Support for Python 3.8 and PyPy3: treq is now tested with these interpreters.
  * `treq.client.HTTPClient.request()` and its aliases no longer raise `UnicodeEncodeError` when passed a Unicode *url* and non-empty *params*.
  * In treq 20.3.0 the *params* argument didn't accept parameter names or values that contain the characters ``&`` or ``#``.
* Wed Mar 25 2020 pgajdos@suse.com
- version update to 20.3.0
  - Python 3.7 support. (`#228 <https://github.com/twisted/treq/issues/228>`__)
  - `treq.testing.RequestTraversalAgent` now passes its memory reactor to the `twisted.web.server.Site` it creates, preventing the ``Site`` from polluting the global reactor. (`#225 <https://github.com/twisted/treq/issues/225>`__)
  - `treq.testing` no longer generates deprecation warnings about ``twisted.test.proto_helpers.MemoryReactor``. (`#253 <https://github.com/twisted/treq/issues/253>`__)
  - The ``download_file.py`` example has been updated to do a streaming download with *unbuffered=True*. (`#233 <https://github.com/twisted/treq/issues/233>`__)
  - The *agent* parameter to `treq.request()` has been documented. (`#235 <https://github.com/twisted/treq/issues/235>`__)
  - The type of the *headers* element of a response tuple passed to `treq.testing.RequestSequence` is now correctly documented as `str`. (`#237 <https://github.com/twisted/treq/issues/237>`__)
  - Drop support for Python 3.4. (`#240 <https://github.com/twisted/treq/issues/240>`__)
  - `#247 <https://github.com/twisted/treq/issues/247>`__, `#248 <https://github.com/twisted/treq/issues/248>`__, `#249 <https://github.com/twisted/treq/issues/249>`__
- deleted patches
  - python37.patch (upstreamed)
  - urlparsing.patch (upstreamed)
* Fri Oct  4 2019 Aleksa Sarai <asarai@suse.com>
- Add service_identity BuildRequires so the integration tests don't fail on
  Leap (required for boo#1153017).
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix build with new Twisted releases:
  * urlparsing.patch
* Thu Mar  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix testrun on python3.7:
  * python37.patch
- Fix macro expansion to run the tests under python3
* Mon Oct 22 2018 Tomáš Chvátal <tchvatal@suse.com>
- Make the tests actually execute
* Sun Oct 14 2018 Jan Engelhardt <jengelh@inai.de>
- Avoid name repetition in summary (rpmlint).
* Thu Oct 11 2018 Tomáš Chvátal <tchvatal@suse.com>
- State all dependnecies properly and execute tests
* Sat Oct  6 2018 ecsos@opensuse.org
- initial version 18.6.0
